-- Name: CAP-011 - CAP and Engage within Zone
-- Author: FlightControl
-- Date Created: 16 January 2017
--
-- # Situation:
--
-- The airplane will patrol in PatrolZone.
-- It will engage when it detects a bogey within the CapEngageZone.
--
-- # Test cases:
-- 
-- 1. Observe the aircraft patrolling.
-- 2. Observe that, when the bogey is within the engage zone, it will engage.
-- 3. After engage, observe that the aircraft returns to the PatrolZone.
-- 4. If you want, you can wait until the aircraft is out of fuel and will land.
--
-- Setup:
-- Create patrol zone in mission editor
-- Create engage zone in mission editor
-- Check patrol aircraft altitude and speed parameters in this script.
-- Create aircraft group, check comm, change freq, check uncontrolled.
-- Add weapons
-- You can add "Start" (if you want to delay start until later in the mission) to a/c triggered actions menu
-- There is no need to add tracks/waypoints. Patrol aircraft will navigate to and from patrol zone without waypoints. 

CapPlane = GROUP:FindByName( "DODGE" )

PatrolZone = ZONE:New( "DODGE PATROL ZONE" )

-- parameters are lowest patrol alt in meters, highest patrol alt in meters, lowest speed in km/h, highest speed in km/h
-- 2500 meters = 8202 feet, 5000 meters = 16400, 7500 meters = 24600 feet, 10000 meters = 33800 feet, 500 km/h = 270 knots, 600 km/h = 324 knots
AICapZone = AI_CAP_ZONE:New( PatrolZone, 2500, 7500, 500, 600 )

EngageZoneGroup = GROUP:FindByName( "DODGE ENGAGE ZONE" )

CapEngageZone = ZONE_POLYGON:New( "DODGE ENGAGE ZONE", EngageZoneGroup )

AICapZone:SetControllable( CapPlane )
AICapZone:SetEngageZone( CapEngageZone ) -- Set the Engage Zone. The AI will only engage when the bogeys are within the CapEngageZone.

AICapZone:__Start( 1 ) -- They should startup, and start patrolling in the PatrolZone.